///////////////////////////////////////////////////////////////////////////
////   Library for a MicroChip 24LC01B configured for a x8 org         ////
////                                                                   ////
////   init_ext_eeprom();    Call before the other functions are used  ////
////                                                                   ////
////   write_ext_eeprom(a, d);  Write the byte d to the address a      ////
////                                                                   ////
////   d = read_ext_eeprom(a);   Read the byte d from the address a    ////
////                                                                   ////
////   The main program may define eeprom_sda                          ////
////   and eeprom_scl to override the defaults below.                  ////
////                                                                   ////
////                                                                   ////
////   Comentrios em portugus  e alteraes para que funes aceitem ////
////   o nmero do banco feitos por Mrcio Jos Soares                 ////
////                                                                   ////
///////////////////////////////////////////////////////////////////////////
////        (C) Copyright 1996,1997 Custom Computer Services           ////
//// This source code may only be used by licensed users of the CCS C  ////
//// compiler.  This source code may only be distributed to other      ////
//// licensed users of the CCS C compiler.  No other use, reproduction ////
//// or distribution is permitted without written permission.          ////
//// Derivative programs created using this software in object code    ////
//// form are not restricted in any way.                               ////
///////////////////////////////////////////////////////////////////////////

//******************************************************************************
// Definies do mdulo
//******************************************************************************
#use i2c(master, sda=EEPROM_SDA, scl=EEPROM_SCL, SLOW)

#define EEPROM_ADDRESS byte                  //tipo do dado
#define EEPROM_SIZE    (int)(TAM_EEPROM/8)   //tamanho da eeprom em bytes

//******************************************************************************
// Funes do mdulo
//******************************************************************************

//******************************************************************************
// Funo init_ext_eeprom - inicia pinos
//
// Entradas - nenhuma
// Saidas   - nenhuma
//******************************************************************************
void init_ext_eeprom(){
   output_float(eeprom_scl);        //inicializa pinos
   output_float(eeprom_sda);
}

//******************************************************************************
// Funo write_ext_eeprom - escreve um byte no endereo especificado
//
// Entradas - endereo, banco e dado
// Saidas   - nenhuma
//******************************************************************************
void write_ext_eeprom(byte bank, byte address, byte data){

   i2c_start();               //envia sinal de start (SCL 1 -> 0)
   i2c_write(bank);           //envia endereo do dispositivo/escrita
   i2c_write(address);        //envia endereo na memria do dispositivo
   i2c_write(data);           //envia dado a ser escrito
   i2c_stop();                //envia sinal de stop (SCL 0 -> 1)
   delay_ms(11);              //aguarda perodo
}

//******************************************************************************
// Funo read_ext_eeprom - l um byte do endereo especificado
//
// Entradas - endereo e banco
// Saidas   - dado
//******************************************************************************
byte read_ext_eeprom(byte bank, byte address){

   byte data;

   i2c_start();               //envia sinal de start (SCL 1 -> 0)
   i2c_write(bank & 0xFE);    //envia endereo do dispositivo/escrita
   i2c_write(address);        //envia endereo na memria do dispositivo
   i2c_start();               //envia sinal de start (SCL 1 -> 0)
   i2c_write(bank);           //envia endereo do dispositivo/leitura
   data=i2c_read(0);          //recebe dado contido no endereo
   i2c_stop();                //envia sinal de stop (SCL 0 -> 1)
   delay_ms(11);
   return(data);              //retorna dado
}

