//******************************************************************************
// Arquivo pic_sound.h
// Desenvolvido por Mrcio Jos Soares
// diretrizes de pr-compilao para mdulo pic_sound.c
//******************************************************************************

//******************************************************************************
// Arquivos includos neste mdulo
//******************************************************************************
#include <16F628.h>

//******************************************************************************
// Configuraes para o microcontrolador PIC16F628
//******************************************************************************
#use delay(clock=4000000,RESTART_WDT)
#priority RDA, timer1

//******************************************************************************
// Configurao dos fuses do microcontrolador PIC16F628
//******************************************************************************
#fuses INTRC_IO,PUT,WDT,NOBROWNOUT,NOLVP,NOCPD
//INTRC	      Clock interno
//PUT          Ativa tempo de inicializao
//WDT		      Ativa Watch Dog Timer
//NOBROWNOUT	No usa brownout reset
//NOMCLR		   Pino Master Clear usado como I/O
//NOLVP		   No usa baixa voltagem para programao, pino B3 usado como I/O
//NOCPD		   No protege EEPROM

//******************************************************************************
// Configurao da comunicao serial do PIC16F628
//******************************************************************************
#use rs232(baud=9600,parity=N,xmit=PIN_B2,rcv=PIN_B1,bits=8)

//******************************************************************************
// Definies para o mdulo - teste_DS1302
//******************************************************************************
#locate  rxreg    =  0x1a        //endereo do registrador p/ byte recebido

#define  LED         PIN_A4      //pino do LED
#define  EEPROM_SDA  PIN_A1      //dados para 24C01
#define  EEPROM_SCL  PIN_A0      //CLK para 24C01

#ifndef NCIS
#define NCIS    4                //nmero de CIs utilizados (1 a 8)
#endif

//******************************************************************************
// Permite selecionar o tipo de memria desejada: 24C01 ou 24C02
//******************************************************************************
#ifndef TAM_EEPROM
#define TAM_EEPROM   1024        //1024 p/ 24C01 ou 2048 p/ 24C02
#endif
//******************************************************************************

#define TBITS        (TAM_EEPROM/8)    //usado para dump de memria
#define LINHAS       (TBITS/16)
#define COLUNAS      (TBITS/8)

//******************************************************************************
//Constantes Globais para o mdulo MEMO_CTRL_24C01 - ROM
//******************************************************************************
const unsigned char msg1[]={"\n\rMenu principal"};
const unsigned char msg2[]={"\n\r1 - Seleciona banco (selec.->"};
const unsigned char msg3[]={"\n\r2 - Apaga banco"};
const unsigned char msg4[]={"\n\r3 - Grava dado"};
const unsigned char msg5[]={"\n\r4 - Apaga dado"};
const unsigned char msg6[]={"\n\r5 - Dump da memria em ASCII"};
const unsigned char msg7[]={"\n\r6 - Dump da memria em HEXA"};
const unsigned char msg8[]={"\n\rEntre com sua opcao->"};


//******************************************************************************
//Variveis Globais para o mdulo teste_DS1302 - RAM
//******************************************************************************
byte banco;             //nmero do banco em trabalho
byte endereco;          //endereco no banco em trabalho
byte dado;              //dado
byte maq_est;           //mquina de estado
